@@ -125,8 +125,10 @@ void KateDocumentTest::testWrapParagraph()
     KTextEditor::DocumentPrivate doc(false, false);
     doc.setWordWrapAt(30); // Keep needed test data small
 
-    const QString before = QLatin1String("aaaaa a aaaa\naaaaa aaa aa aaaa aaaa \naaaa a aaa aaaaaaa a aaaa\n\nxxxxx x\nxxxx xxxxx\nxxx xx xxxx \nxxxx xxxx x xxx xxxxxxx x xxxx");
-    const QString after = QLatin1String("aaaaa a aaaa aaaaa aaa aa aaaa \naaaa aaaa a aaa aaaaaaa a aaaa\n\nxxxxx x xxxx xxxxx xxx xx xxxx \nxxxx xxxx x xxx xxxxxxx x xxxx");
+    const QString before =
+        QLatin1String("aaaaa a aaaa\naaaaa aaa aa aaaa aaaa \naaaa a aaa aaaaaaa a aaaa\n\nxxxxx x\nxxxx xxxxx\nxxx xx xxxx \nxxxx xxxx x xxx xxxxxxx x xxxx");
+    const QString after =
+        QLatin1String("aaaaa a aaaa aaaaa aaa aa aaaa \naaaa aaaa a aaa aaaaaaa a aaaa\n\nxxxxx x xxxx xxxxx xxx xx xxxx \nxxxx xxxx x xxx xxxxxxx x xxxx");
 
     doc.setWordWrap(false); // First we try with disabled hard wrap
     doc.setText(before);
@@ -159,8 +161,8 @@ void KateDocumentTest::testReplaceQStringList()
 void KateDocumentTest::testMovingInterfaceSignals()
 {
     KTextEditor::DocumentPrivate *doc = new KTextEditor::DocumentPrivate;
-    QSignalSpy aboutToDeleteSpy(doc, SIGNAL(aboutToDeleteMovingInterfaceContent(KTextEditor::Document *)));
-    QSignalSpy aboutToInvalidateSpy(doc, SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document *)));
+    QSignalSpy aboutToDeleteSpy(doc, &KTextEditor::DocumentPrivate::aboutToDeleteMovingInterfaceContent);
+    QSignalSpy aboutToInvalidateSpy(doc, &KTextEditor::DocumentPrivate::aboutToInvalidateMovingInterfaceContent);
 
     QCOMPARE(doc->revision(), qint64(0));
 
@@ -197,7 +199,10 @@ void KateDocumentTest::testSetTextPerformance()
 
     KTextEditor::DocumentPrivate doc;
     MovingRangeInvalidator invalidator;
-    connect(&doc, SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document *)), &invalidator, SLOT(aboutToInvalidateMovingInterfaceContent()));
+    connect(&doc,
+            &KTextEditor::DocumentPrivate::aboutToInvalidateMovingInterfaceContent,
+            &invalidator,
+            &MovingRangeInvalidator::aboutToInvalidateMovingInterfaceContent);
 
     QString text;
     QVector<Range> ranges;
@@ -485,7 +490,7 @@ void KateDocumentTest::testInsertNewline()
         "this is line2\n");
 
     SignalHandler handler;
-    connect(&doc, SIGNAL(textInserted(KTextEditor::Document *, KTextEditor::Range)), &handler, SLOT(slotNewlineInserted(KTextEditor::Document *, KTextEditor::Range)));
+    connect(&doc, &KTextEditor::DocumentPrivate::textInserted, &handler, &SignalHandler::slotNewlineInserted);
     doc.editWrapLine(1, 4);
 }
 
