@@ -1,21 +1,7 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2010 Christoph Cullmann <cullmann@kde.org>
 
-    Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "katetextblock.h"
@@ -120,21 +106,15 @@ void TextBlock::wrapLine(const KTextEditor::Cursor &position, int fixStartLinesS
         m_lines.at(line)->markAsModified(true);
     }
 
-    /**
-     * fix all start lines
-     * we need to do this NOW, else the range update will FAIL!
-     * bug 313759
-     */
+    // fix all start lines
+    // we need to do this NOW, else the range update will FAIL!
+    // bug 313759
     m_buffer->fixStartLines(fixStartLinesStartIndex);
 
-    /**
-     * notify the text history
-     */
+    // notify the text history
     m_buffer->history().wrapLine(position);
 
-    /**
-     * cursor and range handling below
-     */
+    // cursor and range handling below
 
     // no cursors will leave or join this block
 
@@ -187,7 +167,12 @@ void TextBlock::wrapLine(const KTextEditor::Cursor &position, int fixStartLinesS
     // we might need to invalidate ranges or notify about their changes
     // checkValidity might trigger delete of the range!
     for (TextRange *range : qAsConst(changedRanges)) {
-        range->checkValidity();
+        // we need to do updateRange to ALWAYS ensure the line => range and back cache is updated
+        // see MovingRangeTest::testLineWrapOrUnwrapUpdateRangeForLineCache
+        updateRange(range);
+
+        // in addition: ensure that we really invalidate bad ranges!
+        range->checkValidity(range->toLineRange());
     }
 }
 
@@ -221,21 +206,15 @@ void TextBlock::unwrapLine(int line, TextBlock *previousBlock, int fixStartLines
         // patch startLine of this block
         --m_startLine;
 
-        /**
-         * fix all start lines
-         * we need to do this NOW, else the range update will FAIL!
-         * bug 313759
-         */
+        // fix all start lines
+        // we need to do this NOW, else the range update will FAIL!
+        // bug 313759
         m_buffer->fixStartLines(fixStartLinesStartIndex);
 
-        /**
-         * notify the text history in advance
-         */
+        // notify the text history in advance
         m_buffer->history().unwrapLine(startLine() + line, oldSizeOfPreviousLine);
 
-        /**
-         * cursor and range handling below
-         */
+        // cursor and range handling below
 
         // no cursors in this block and the previous one, no work to do..
         if (m_cursors.empty() && previousBlock->m_cursors.empty()) {
@@ -292,7 +271,7 @@ void TextBlock::unwrapLine(int line, TextBlock *previousBlock, int fixStartLines
             previousBlock->updateRange(range);
 
             // afterwards check validity, might delete this range!
-            range->checkValidity();
+            range->checkValidity(range->toLineRange());
         }
 
         // be done
@@ -306,7 +285,8 @@ void TextBlock::unwrapLine(int line, TextBlock *previousBlock, int fixStartLines
         m_lines.at(line - 1)->textReadWrite().append(m_lines.at(line)->text());
     }
 
-    const bool lineChanged = (oldSizeOfPreviousLine > 0 && m_lines.at(line - 1)->markedAsModified()) || (sizeOfCurrentLine > 0 && (oldSizeOfPreviousLine > 0 || m_lines.at(line)->markedAsModified()));
+    const bool lineChanged = (oldSizeOfPreviousLine > 0 && m_lines.at(line - 1)->markedAsModified())
+        || (sizeOfCurrentLine > 0 && (oldSizeOfPreviousLine > 0 || m_lines.at(line)->markedAsModified()));
     m_lines.at(line - 1)->markAsModified(lineChanged);
     if (oldSizeOfPreviousLine == 0 && m_lines.at(line)->markedAsSavedOnDisk()) {
         m_lines.at(line - 1)->markAsSavedOnDisk(true);
@@ -314,21 +294,15 @@ void TextBlock::unwrapLine(int line, TextBlock *previousBlock, int fixStartLines
 
     m_lines.erase(m_lines.begin() + line);
 
-    /**
-     * fix all start lines
-     * we need to do this NOW, else the range update will FAIL!
-     * bug 313759
-     */
+    // fix all start lines
+    // we need to do this NOW, else the range update will FAIL!
+    // bug 313759
     m_buffer->fixStartLines(fixStartLinesStartIndex);
 
-    /**
-     * notify the text history in advance
-     */
+    // notify the text history in advance
     m_buffer->history().unwrapLine(startLine() + line, oldSizeOfPreviousLine);
 
-    /**
-     * cursor and range handling below
-     */
+    // cursor and range handling below
 
     // no cursors in this block, no work to do..
     if (m_cursors.empty()) {
@@ -364,7 +338,12 @@ void TextBlock::unwrapLine(int line, TextBlock *previousBlock, int fixStartLines
     // we might need to invalidate ranges or notify about their changes
     // checkValidity might trigger delete of the range!
     for (TextRange *range : qAsConst(changedRanges)) {
-        range->checkValidity();
+        // we need to do updateRange to ALWAYS ensure the line => range and back cache is updated
+        // see MovingRangeTest::testLineWrapOrUnwrapUpdateRangeForLineCache
+        updateRange(range);
+
+        // in addition: ensure that we really invalidate bad ranges!
+        range->checkValidity(range->toLineRange());
     }
 }
 
@@ -385,14 +364,10 @@ void TextBlock::insertText(const KTextEditor::Cursor &position, const QString &t
     // insert text
     textOfLine.insert(position.column(), text);
 
-    /**
-     * notify the text history
-     */
+    // notify the text history
     m_buffer->history().insertText(position, text.size(), oldLength);
 
-    /**
-     * cursor and range handling below
-     */
+    // cursor and range handling below
 
     // no cursors in this block, no work to do..
     if (m_cursors.empty()) {
@@ -437,7 +412,7 @@ void TextBlock::insertText(const KTextEditor::Cursor &position, const QString &t
     // we might need to invalidate ranges or notify about their changes
     // checkValidity might trigger delete of the range!
     for (TextRange *range : qAsConst(changedRanges)) {
-        range->checkValidity();
+        range->checkValidity(range->toLineRange());
     }
 }
 
@@ -463,14 +438,10 @@ void TextBlock::removeText(const KTextEditor::Range &range, QString &removedText
     textOfLine.remove(range.start().column(), range.end().column() - range.start().column());
     m_lines.at(line)->markAsModified(true);
 
-    /**
-     * notify the text history
-     */
+    // notify the text history
     m_buffer->history().removeText(range, oldLength);
 
-    /**
-     * cursor and range handling below
-     */
+    // cursor and range handling below
 
     // no cursors in this block, no work to do..
     if (m_cursors.empty()) {
@@ -510,7 +481,7 @@ void TextBlock::removeText(const KTextEditor::Range &range, QString &removedText
     // we might need to invalidate ranges or notify about their changes
     // checkValidity might trigger delete of the range!
     for (TextRange *range : qAsConst(changedRanges)) {
-        range->checkValidity();
+        range->checkValidity(range->toLineRange());
     }
 }
 
@@ -553,8 +524,14 @@ TextBlock *TextBlock::splitBlock(int fromLine)
     }
 
     // fix ALL ranges!
-    const QList<TextRange *> allRanges = m_uncachedRanges.values() + m_cachedLineForRanges.keys();
-    for (TextRange *range : qAsConst(allRanges)) {
+    // copy is necessary as update range may modify the uncached ranges
+    std::vector<TextRange *> allRanges;
+    allRanges.reserve(m_uncachedRanges.size() + m_cachedLineForRanges.size());
+    std::for_each(m_cachedLineForRanges.begin(), m_cachedLineForRanges.end(), [&allRanges](const std::pair<TextRange *, int> &pair) {
+        allRanges.push_back(pair.first);
+    });
+    allRanges.insert(allRanges.end(), m_uncachedRanges.begin(), m_uncachedRanges.end());
+    for (TextRange *range : allRanges) {
         // update both blocks
         updateRange(range);
         newBlock->updateRange(range);
@@ -582,8 +559,14 @@ void TextBlock::mergeBlock(TextBlock *targetBlock)
     m_lines.clear();
 
     // fix ALL ranges!
-    const QList<TextRange *> allRanges = m_uncachedRanges.values() + m_cachedLineForRanges.keys();
-    for (TextRange *range : qAsConst(allRanges)) {
+    // copy is necessary as update range may modify the uncached ranges
+    std::vector<TextRange *> allRanges;
+    allRanges.reserve(m_uncachedRanges.size() + m_cachedLineForRanges.size());
+    std::for_each(m_cachedLineForRanges.begin(), m_cachedLineForRanges.end(), [&allRanges](const std::pair<TextRange *, int> &pair) {
+        allRanges.push_back(pair.first);
+    });
+    allRanges.insert(allRanges.end(), m_uncachedRanges.begin(), m_uncachedRanges.end());
+    for (TextRange *range : allRanges) {
         // update both blocks
         updateRange(range);
         targetBlock->updateRange(range);
@@ -638,6 +621,39 @@ void TextBlock::clearBlockContent(TextBlock *targetBlock)
     m_lines.clear();
 }
 
+QVector<TextRange *> TextBlock::rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly) const
+{
+    const auto cachedRanges = cachedRangesForLine(line);
+    QVector<TextRange *> ranges;
+    ranges.reserve(m_uncachedRanges.size() + cachedRanges.size());
+
+    auto predicate = [line, view, rangesWithAttributeOnly](TextRange *range) {
+        if (rangesWithAttributeOnly && !range->hasAttribute()) {
+            return false;
+        }
+
+        // we want ranges for no view, but this one's attribute is only valid for views
+        if (!view && range->attributeOnlyForViews()) {
+            return false;
+        }
+
+        // the range's attribute is not valid for this view
+        if (range->view() && range->view() != view) {
+            return false;
+        }
+
+        // if line is in the range, ok
+        if (range->startInternal().lineInternal() <= line && line <= range->endInternal().lineInternal()) {
+            return true;
+        }
+        return false;
+    };
+
+    std::copy_if(cachedRanges.begin(), cachedRanges.end(), std::back_inserter(ranges), predicate);
+    std::copy_if(m_uncachedRanges.begin(), m_uncachedRanges.end(), std::back_inserter(ranges), predicate);
+    return ranges;
+}
+
 void TextBlock::markModifiedLinesAsSaved()
 {
     // mark all modified lines as saved
@@ -650,109 +666,82 @@ void TextBlock::markModifiedLinesAsSaved()
 
 void TextBlock::updateRange(TextRange *range)
 {
-    /**
-     * get some simple facts about our nice range
-     */
+    // get some simple facts about our nice range
     const int startLine = range->startInternal().lineInternal();
     const int endLine = range->endInternal().lineInternal();
     const bool isSingleLine = startLine == endLine;
 
-    /**
-     * perhaps remove range and be done
-     */
+    // perhaps remove range and be done
     if ((endLine < m_startLine) || (startLine >= (m_startLine + lines()))) {
         removeRange(range);
         return;
     }
 
-    /**
-     * The range is still a single-line range, and is still cached to the correct line.
-     */
-    if (isSingleLine && m_cachedLineForRanges.contains(range) && (m_cachedLineForRanges.value(range) == startLine - m_startLine)) {
-        return;
+    // The range is still a single-line range, and is still cached to the correct line.
+    if (isSingleLine) {
+        auto it = m_cachedLineForRanges.find(range);
+        if (it != m_cachedLineForRanges.end() && it->second == startLine - m_startLine) {
+            return;
+        }
     }
 
-    /**
-     * The range is still a multi-line range, and is already in the correct set.
-     */
+    // The range is still a multi-line range, and is already in the correct set.
     if (!isSingleLine && m_uncachedRanges.contains(range)) {
         return;
     }
 
-    /**
-     * remove, if already there!
-     */
+    // remove, if already there!
     removeRange(range);
 
-    /**
-     * simple case: multi-line range
-     */
+    // simple case: multi-line range
     if (!isSingleLine) {
-        /**
-         * The range cannot be cached per line, as it spans multiple lines
-         */
-        m_uncachedRanges.insert(range);
+        // The range cannot be cached per line, as it spans multiple lines
+        m_uncachedRanges.append(range);
         return;
     }
 
-    /**
-     * The range is contained by a single line, put it into the line-cache
-     */
+    // The range is contained by a single line, put it into the line-cache
     const int lineOffset = startLine - m_startLine;
 
-    /**
-     * enlarge cache if needed
-     */
+    // enlarge cache if needed
     if (m_cachedRangesForLine.size() <= lineOffset) {
         m_cachedRangesForLine.resize(lineOffset + 1);
     }
 
-    /**
-     * insert into mapping
-     */
+    // insert into mapping
     m_cachedRangesForLine[lineOffset].insert(range);
     m_cachedLineForRanges[range] = lineOffset;
 }
 
 void TextBlock::removeRange(TextRange *range)
 {
-    /**
-     * uncached range? remove it and be done
-     */
-    if (m_uncachedRanges.remove(range)) {
-        /**
-         * must be only uncached!
-         */
-        Q_ASSERT(!m_cachedLineForRanges.contains(range));
+    // uncached range? remove it and be done
+    int pos = m_uncachedRanges.indexOf(range);
+    if (pos != -1) {
+        m_uncachedRanges.remove(pos);
+        // must be only uncached!
+        Q_ASSERT(m_cachedLineForRanges.find(range) == m_cachedLineForRanges.end());
         return;
     }
 
-    /**
-     * cached range?
-     */
-    QHash<TextRange *, int>::iterator it = m_cachedLineForRanges.find(range);
+    // cached range?
+    auto it = m_cachedLineForRanges.find(range);
     if (it != m_cachedLineForRanges.end()) {
-        /**
-         * must be only cached!
-         */
+        // must be only cached!
         Q_ASSERT(!m_uncachedRanges.contains(range));
 
-        /**
-         * query the range from cache, must be there
-         */
-        Q_ASSERT(m_cachedRangesForLine.at(*it).contains(range));
+        int line = it->second;
 
-        /**
-         * remove it and be done
-         */
-        m_cachedRangesForLine[*it].remove(range);
+        // query the range from cache, must be there
+        Q_ASSERT(m_cachedRangesForLine.at(line).contains(range));
+
+        // remove it and be done
+        m_cachedRangesForLine[line].remove(range);
         m_cachedLineForRanges.erase(it);
         return;
     }
 
-    /**
-     * else: range was not for this block, just do nothing, removeRange should be "safe" to use
-     */
+    // else: range was not for this block, just do nothing, removeRange should be "safe" to use
 }
 
 }
