@@ -49,8 +49,11 @@ public:
     KateCompletionTree *treeView() const;
 
     bool isCompletionActive() const;
-    void startCompletion(KTextEditor::CodeCompletionModel::InvocationType invocationType, const QList<KTextEditor::CodeCompletionModel *> &models = QList<KTextEditor::CodeCompletionModel *>());
-    void startCompletion(const KTextEditor::Range &word, KTextEditor::CodeCompletionModel *model, KTextEditor::CodeCompletionModel::InvocationType invocationType = KTextEditor::CodeCompletionModel::ManualInvocation);
+    void startCompletion(KTextEditor::CodeCompletionModel::InvocationType invocationType,
+                         const QList<KTextEditor::CodeCompletionModel *> &models = QList<KTextEditor::CodeCompletionModel *>());
+    void startCompletion(const KTextEditor::Range &word,
+                         KTextEditor::CodeCompletionModel *model,
+                         KTextEditor::CodeCompletionModel::InvocationType invocationType = KTextEditor::CodeCompletionModel::ManualInvocation);
     void startCompletion(const KTextEditor::Range &word,
                          const QList<KTextEditor::CodeCompletionModel *> &models = QList<KTextEditor::CodeCompletionModel *>(),
                          KTextEditor::CodeCompletionModel::InvocationType invocationType = KTextEditor::CodeCompletionModel::ManualInvocation);
@@ -58,7 +61,7 @@ public:
 
 public Q_SLOTS:
     // Executed when return is pressed while completion is active.
-    void execute();
+    bool execute();
     void cursorDown();
     void cursorUp();
 
