@@ -1,23 +1,12 @@
-// This file is part of the KDE libraries
-// Copyright (C) 2005 Christoph Cullmann <cullmann@kde.org>
-// Copyright (C) 2005 Joseph Wenninger <jowenn@kde.org>
-// Copyright (C) 2006-2018 Dominik Haumann <dhaumann@kde.org>
-// Copyright (C) 2008 Paul Giannaros <paul@giannaros.org>
-// Copyright (C) 2010 Joseph Wenninger <jowenn@kde.org>
-//
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License version 2 as published by the Free Software Foundation.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library; see the file COPYING.LIB.  If not, write to
-// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-// Boston, MA 02110-1301, USA.
+/*
+    SPDX-FileCopyrightText: 2005 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2005 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2006-2018 Dominik Haumann <dhaumann@kde.org>
+    SPDX-FileCopyrightText: 2008 Paul Giannaros <paul@giannaros.org>
+    SPDX-FileCopyrightText: 2010 Joseph Wenninger <jowenn@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "katescriptmanager.h"
 
@@ -26,21 +15,21 @@
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
-#include <QStringList>
-#include <QMap>
-#include <QUuid>
-#include <QJsonDocument>
-#include <QJsonValue>
-#include <QJsonObject>
 #include <QJsonArray>
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QJsonValue>
+#include <QMap>
 #include <QRegularExpression>
+#include <QStringList>
+#include <QUuid>
 
-#include <KLocalizedString>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
 
-#include "kateglobal.h"
 #include "katecmd.h"
+#include "kateglobal.h"
 #include "katepartdebug.h"
 
 KateScriptManager *KateScriptManager::m_instance = nullptr;
@@ -67,7 +56,8 @@ KateIndentScript *KateScriptManager::indenter(const QString &language)
         // don't overwrite if there is already a result with a higher priority
         if (highestPriorityIndenter && indenter->indentHeader().priority() < highestPriorityIndenter->indentHeader().priority()) {
 #ifdef DEBUG_SCRIPTMANAGER
-            qCDebug(LOG_KTE) << "Not overwriting indenter for" << language << "as the priority isn't big enough (" << indenter->indentHeader().priority() << '<' << highestPriorityIndenter->indentHeader().priority() << ')';
+            qCDebug(LOG_KTE) << "Not overwriting indenter for" << language << "as the priority isn't big enough (" << indenter->indentHeader().priority() << '<'
+                             << highestPriorityIndenter->indentHeader().priority() << ')';
 #endif
         } else {
             highestPriorityIndenter = indenter;
@@ -113,9 +103,7 @@ void KateScriptManager::collect()
     m_languageToIndenters.clear();
     m_indentationScriptMap.clear();
 
-    /**
-     * now, we search all kinds of known scripts
-     */
+    // now, we search all kinds of known scripts
     for (const auto &type : {QLatin1String("indentation"), QLatin1String("commands")}) {
         // basedir for filesystem lookup
         const QString basedir = QLatin1String("/katepart5/script/") + type;
@@ -146,34 +134,24 @@ void KateScriptManager::collect()
         // iterate through the files and read info out of cache or file, no double loading of same scripts
         QSet<QString> unique;
         for (const QString &fileName : qAsConst(list)) {
-            /**
-             * get file basename
-             */
+            // get file basename
             const QString baseName = QFileInfo(fileName).baseName();
 
-            /**
-             * only load scripts once, even if multiple installed variants found!
-             */
+            // only load scripts once, even if multiple installed variants found!
             if (unique.contains(baseName))
                 continue;
 
-            /**
-             * remember the script
-             */
+            // remember the script
             unique.insert(baseName);
 
-            /**
-             * open file or skip it
-             */
+            // open file or skip it
             QFile file(fileName);
             if (!file.open(QIODevice::ReadOnly)) {
                 qCDebug(LOG_KTE) << "Script parse error: Cannot open file " << qPrintable(fileName) << '\n';
                 continue;
             }
 
-            /**
-             * search json header or skip this file
-             */
+            // search json header or skip this file
             QByteArray fileContent = file.readAll();
             int startOfJson = fileContent.indexOf('{');
             if (startOfJson < 0) {
@@ -191,19 +169,16 @@ void KateScriptManager::collect()
             }
             endOfJson += 2; // we want the end including the } but not the ;
 
-            /**
-             * parse json header or skip this file
-             */
+            // parse json header or skip this file
             QJsonParseError error;
             const QJsonDocument metaInfo(QJsonDocument::fromJson(fileContent.mid(startOfJson, endOfJson - startOfJson), &error));
             if (error.error || !metaInfo.isObject()) {
-                qCDebug(LOG_KTE) << "Script parse error: Cannot parse json header at start of file " << qPrintable(fileName) << error.errorString() << endOfJson << fileContent.mid(endOfJson - 25, 25).replace('\n', ' ');
+                qCDebug(LOG_KTE) << "Script parse error: Cannot parse json header at start of file " << qPrintable(fileName) << error.errorString() << endOfJson
+                                 << fileContent.mid(endOfJson - 25, 25).replace('\n', ' ');
                 continue;
             }
 
-            /**
-             * remember type
-             */
+            // remember type
             KateScriptHeader generalHeader;
             if (type == QLatin1String("indentation")) {
                 generalHeader.setScriptType(Kate::ScriptType::Indentation);
@@ -222,58 +197,60 @@ void KateScriptManager::collect()
 
             // now, cast accordingly based on type
             switch (generalHeader.scriptType()) {
-                case Kate::ScriptType::Indentation: {
-                    KateIndentScriptHeader indentHeader;
-                    indentHeader.setName(metaInfoObject.value(QStringLiteral("name")).toString());
-                    indentHeader.setBaseName(baseName);
-                    if (indentHeader.name().isNull()) {
-                        qCDebug(LOG_KTE) << "Script value error: No name specified in script meta data: " << qPrintable(fileName) << '\n' << "-> skipping indenter" << '\n';
-                        continue;
-                    }
+            case Kate::ScriptType::Indentation: {
+                KateIndentScriptHeader indentHeader;
+                indentHeader.setName(metaInfoObject.value(QStringLiteral("name")).toString());
+                indentHeader.setBaseName(baseName);
+                if (indentHeader.name().isNull()) {
+                    qCDebug(LOG_KTE) << "Script value error: No name specified in script meta data: " << qPrintable(fileName) << '\n'
+                                     << "-> skipping indenter" << '\n';
+                    continue;
+                }
 
-                    // required style?
-                    indentHeader.setRequiredStyle(metaInfoObject.value(QStringLiteral("required-syntax-style")).toString());
-                    // which languages does this support?
-                    QStringList indentLanguages = jsonToStringList(metaInfoObject.value(QStringLiteral("indent-languages")));
-                    if (!indentLanguages.isEmpty()) {
-                        indentHeader.setIndentLanguages(indentLanguages);
-                    } else {
-                        indentHeader.setIndentLanguages(QStringList() << indentHeader.name());
+                // required style?
+                indentHeader.setRequiredStyle(metaInfoObject.value(QStringLiteral("required-syntax-style")).toString());
+                // which languages does this support?
+                QStringList indentLanguages = jsonToStringList(metaInfoObject.value(QStringLiteral("indent-languages")));
+                if (!indentLanguages.isEmpty()) {
+                    indentHeader.setIndentLanguages(indentLanguages);
+                } else {
+                    indentHeader.setIndentLanguages(QStringList() << indentHeader.name());
 
 #ifdef DEBUG_SCRIPTMANAGER
-                        qCDebug(LOG_KTE) << "Script value warning: No indent-languages specified for indent "
-                                         << "script " << qPrintable(fileName) << ". Using the name (" << qPrintable(indentHeader.name()) << ")\n";
+                    qCDebug(LOG_KTE) << "Script value warning: No indent-languages specified for indent "
+                                     << "script " << qPrintable(fileName) << ". Using the name (" << qPrintable(indentHeader.name()) << ")\n";
 #endif
-                    }
-                    // priority
-                    indentHeader.setPriority(metaInfoObject.value(QStringLiteral("priority")).toInt());
-
-                    KateIndentScript *script = new KateIndentScript(fileName, indentHeader);
-                    script->setGeneralHeader(generalHeader);
-                    for (const QString &language : indentHeader.indentLanguages()) {
-                        m_languageToIndenters[language.toLower()].push_back(script);
-                    }
-
-                    m_indentationScriptMap.insert(indentHeader.baseName(), script);
-                    m_indentationScripts.append(script);
-                    break;
                 }
-                case Kate::ScriptType::CommandLine: {
-                    KateCommandLineScriptHeader commandHeader;
-                    commandHeader.setFunctions(jsonToStringList(metaInfoObject.value(QStringLiteral("functions"))));
-                    commandHeader.setActions(metaInfoObject.value(QStringLiteral("actions")).toArray());
-                    if (commandHeader.functions().isEmpty()) {
-                        qCDebug(LOG_KTE) << "Script value error: No functions specified in script meta data: " << qPrintable(fileName) << '\n' << "-> skipping script" << '\n';
-                        continue;
-                    }
-                    KateCommandLineScript *script = new KateCommandLineScript(fileName, commandHeader);
-                    script->setGeneralHeader(generalHeader);
-                    m_commandLineScripts.push_back(script);
-                    break;
+                // priority
+                indentHeader.setPriority(metaInfoObject.value(QStringLiteral("priority")).toInt());
+
+                KateIndentScript *script = new KateIndentScript(fileName, indentHeader);
+                script->setGeneralHeader(generalHeader);
+                for (const QString &language : indentHeader.indentLanguages()) {
+                    m_languageToIndenters[language.toLower()].push_back(script);
                 }
-                case Kate::ScriptType::Unknown:
-                default:
-                    qCDebug(LOG_KTE) << "Script value warning: Unknown type ('" << qPrintable(type) << "'): " << qPrintable(fileName) << '\n';
+
+                m_indentationScriptMap.insert(indentHeader.baseName(), script);
+                m_indentationScripts.append(script);
+                break;
+            }
+            case Kate::ScriptType::CommandLine: {
+                KateCommandLineScriptHeader commandHeader;
+                commandHeader.setFunctions(jsonToStringList(metaInfoObject.value(QStringLiteral("functions"))));
+                commandHeader.setActions(metaInfoObject.value(QStringLiteral("actions")).toArray());
+                if (commandHeader.functions().isEmpty()) {
+                    qCDebug(LOG_KTE) << "Script value error: No functions specified in script meta data: " << qPrintable(fileName) << '\n'
+                                     << "-> skipping script" << '\n';
+                    continue;
+                }
+                KateCommandLineScript *script = new KateCommandLineScript(fileName, commandHeader);
+                script->setGeneralHeader(generalHeader);
+                m_commandLineScripts.push_back(script);
+                break;
+            }
+            case Kate::ScriptType::Unknown:
+            default:
+                qCDebug(LOG_KTE) << "Script value warning: Unknown type ('" << qPrintable(type) << "'): " << qPrintable(fileName) << '\n';
             }
         }
     }
@@ -298,7 +275,7 @@ void KateScriptManager::collect()
 void KateScriptManager::reload()
 {
     collect();
-    emit reloaded();
+    Q_EMIT reloaded();
 }
 
 /// Kate::Command stuff
@@ -306,9 +283,10 @@ void KateScriptManager::reload()
 bool KateScriptManager::exec(KTextEditor::View *view, const QString &_cmd, QString &errorMsg, const KTextEditor::Range &)
 {
     Q_UNUSED(view)
+    Q_UNUSED(errorMsg)
 
-    QVector<QStringRef> args = _cmd.splitRef(QRegularExpression(QStringLiteral("\\s+")), QString::SkipEmptyParts);
-    const QString cmd = args.first().toString();
+    QVector<QStringRef> args = _cmd.splitRef(QRegularExpression(QStringLiteral("\\s+")), Qt::SkipEmptyParts);
+    const QStringRef cmd = args.first();
 
     if (cmd == QLatin1String("reload-scripts")) {
         reload();
