@@ -42,7 +42,7 @@ InsertViMode::InsertViMode(InputModeManager *viInputModeManager, KTextEditor::Vi
 
     m_isExecutingCompletion = false;
 
-    connect(doc(), SIGNAL(textInserted(KTextEditor::Document *, KTextEditor::Range)), this, SLOT(textInserted(KTextEditor::Document *, KTextEditor::Range)));
+    connect(doc(), &KTextEditor::DocumentPrivate::textInserted, this, &InsertViMode::textInserted);
 }
 
 InsertViMode::~InsertViMode()
@@ -125,7 +125,7 @@ bool InsertViMode::commandDeleteLine()
          * Remove backwards until the first non-space character. If no
          * non-space was found, remove backwards to the first column.
          */
-        QRegExp nonSpace(QLatin1String("\\S"));
+        static const QRegularExpression nonSpace(QStringLiteral("\\S"));
         r.startColumn = getLine().indexOf(nonSpace);
         if (r.startColumn == -1 || r.startColumn >= c.column()) {
             r.startColumn = 0;
@@ -261,9 +261,9 @@ bool InsertViMode::commandInsertContentOfRegister()
     }
 
     if (m == LineWise) {
-        textToInsert.chop(1);                     // remove the last \n
+        textToInsert.chop(1); // remove the last \n
         c.setColumn(doc()->lineLength(c.line())); // paste after the current line and ...
-        textToInsert.prepend(QLatin1Char('\n'));  // ... prepend a \n, so the text starts on a new line
+        textToInsert.prepend(QLatin1Char('\n')); // ... prepend a \n, so the text starts on a new line
 
         cAfter.setLine(cAfter.line() + 1);
         cAfter.setColumn(0);
@@ -289,7 +289,7 @@ bool InsertViMode::commandSwitchToNormalModeForJustOneCommand()
         m_view->setCursorPosition(KTextEditor::Cursor(cursorPos.line(), cursorPos.column() - 1));
     }
     m_viInputModeManager->inputAdapter()->setCaretStyle(KateRenderer::Block);
-    emit m_view->viewModeChanged(m_view, m_view->viewMode());
+    Q_EMIT m_view->viewModeChanged(m_view, m_view->viewMode());
     m_viewInternal->repaint();
     return true;
 }
@@ -344,18 +344,20 @@ bool InsertViMode::handleKeypress(const QKeyEvent *e)
                 return true;
             case Qt::Key_Enter:
             case Qt::Key_Return:
-                if (m_view->completionWidget()->isCompletionActive() && !m_viInputModeManager->macroRecorder()->isReplaying() && !m_viInputModeManager->lastChangeRecorder()->isReplaying()) {
-                    // Filter out Enter/ Return's that trigger a completion when recording macros/ last change stuff; they
-                    // will be replaced with the special code "ctrl-space".
-                    // (This is why there is a "!m_viInputModeManager->isReplayingMacro()" above.)
-                    m_viInputModeManager->doNotLogCurrentKeypress();
-
+                if (m_view->completionWidget()->isCompletionActive() && !m_viInputModeManager->macroRecorder()->isReplaying()
+                    && !m_viInputModeManager->lastChangeRecorder()->isReplaying()) {
                     m_isExecutingCompletion = true;
                     m_textInsertedByCompletion.clear();
-                    m_view->completionWidget()->execute();
-                    completionFinished();
+                    const bool success = m_view->completionWidget()->execute();
                     m_isExecutingCompletion = false;
-                    return true;
+                    if (success) {
+                        // Filter out Enter/ Return's that trigger a completion when recording macros/ last change stuff; they
+                        // will be replaced with the special code "ctrl-space".
+                        // (This is why there is a "!m_viInputModeManager->isReplayingMacro()" above.)
+                        m_viInputModeManager->doNotLogCurrentKeypress();
+                        completionFinished();
+                        return true;
+                    }
                 }
                 Q_FALLTHROUGH();
             default:
@@ -450,7 +452,8 @@ bool InsertViMode::handleKeypress(const QKeyEvent *e)
 
         // is it register ?
         // TODO: add registers such as '/'. See :h <c-r>
-        if ((key >= QLatin1Char('0') && key <= QLatin1Char('9')) || (key >= QLatin1Char('a') && key <= QLatin1Char('z')) || key == QLatin1Char('_') || key == QLatin1Char('-') || key == QLatin1Char('+') || key == QLatin1Char('*') || key == QLatin1Char('"')) {
+        if ((key >= QLatin1Char('0') && key <= QLatin1Char('9')) || (key >= QLatin1Char('a') && key <= QLatin1Char('z')) || key == QLatin1Char('_')
+            || key == QLatin1Char('-') || key == QLatin1Char('+') || key == QLatin1Char('*') || key == QLatin1Char('"')) {
             m_register = key;
         } else {
             return false;
@@ -562,7 +565,8 @@ void InsertViMode::completionFinished()
     } else if (m_textInsertedByCompletion.endsWith(QLatin1String("()")) || m_textInsertedByCompletion.endsWith(QLatin1String("();"))) {
         completionType = Completion::FunctionWithoutArgs;
     }
-    m_viInputModeManager->completionRecorder()->logCompletionEvent(Completion(m_textInsertedByCompletion, KateViewConfig::global()->wordCompletionRemoveTail(), completionType));
+    m_viInputModeManager->completionRecorder()->logCompletionEvent(
+        Completion(m_textInsertedByCompletion, KateViewConfig::global()->wordCompletionRemoveTail(), completionType));
 }
 
 void InsertViMode::textInserted(KTextEditor::Document *document, KTextEditor::Range range)
